/*
        Copyright (c) 2014 by Plexim GmbH
        All rights reserved.

        A free license is granted to anyone to use this software for any legal
        non safety-critical purpose, including commercial applications, provided
        that:
        1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
        2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

        THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
        OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
        FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
        AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
        LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
        OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
        SOFTWARE.
 */

#include "pil.h"
#include "pil_ctrl.h"

#include "main.h"
#include "init.h"
#include "control.h"
#include "calib.h"

uint16_t BackgroundLoopCtr;
struct CTRL_DISPATCH_VARS CtrlDispatchVars;

// Timer Interrupt - use a timer interrupt to call ISR
/*void __attribute__((__interrupt__, no_auto_psv)) _T1Interrupt()
{
    static int timer = 0;
    ControlVars.CounterValue =  P1TMRbits.PTMR;
    CtrlDispatchVars.interruptNesting++;

    PIL_beginInterruptCall();

    IFS0bits.T1IF = 0; 		              // Clear Interrupt Flag

    ControlTask1();
    
    timer++;
    if(timer == 5000)
    {
        LATAbits.LATA0 ^= 1; // Toggle the LED
        timer = 0;
    }

    CtrlDispatchVars.interruptEndTimeStamp = timer;
    CtrlDispatchVars.interruptNesting--;
}*/

// ADC Interrupt - use the ADC interrupt to call ISR
void __attribute__((__interrupt__, no_auto_psv)) _ADC1Interrupt()
{
// code for ADC Interrupt goes here
    static int timer = 0;
    CtrlDispatchVars.interruptNesting++;
    ControlVars.CounterValue =  P1TMRbits.PTMR;
    PIL_beginInterruptCall();
    
    IFS0bits.AD1IF = 0;	              // Clear Interrupt Flag
    
    ControlTask1();
     timer++;
    if(timer >= 5000)
    {
        LATAbits.LATA0 ^= 1; // Toggle the LED
        timer = 0;
    }
    
    CtrlDispatchVars.interruptEndTimeStamp = timer;
    CtrlDispatchVars.interruptNesting--;
}


void PollUart()
{
    while(U1STAbits.URXDA)                    
    {
        // while data is available in receive buffer
        PIL_RA_serialIn(U1RXREG);
        //U1TXREG = U1RXREG;
    }

    if(!U1STAbits.UTXBF)
    {
        // transmit buffer empty
        int16_t ch;
        if(PIL_RA_serialOut(&ch))
	{
            U1TXREG = ch;
	}
    }

    if(U1STAbits.OERR)
    {
        U1STAbits.OERR = 0;    // clear RX buffer overrun error
    }
}

void ResetControlDispatcher()
{
    CtrlDispatchVars.interruptNesting = 0;
}

void InitControlDispatcher()
{
    T1CONbits.TCS = 0;      // Use internal clock (FCY)
    T1CONbits.TCKPS = 0;    // 1:1 prescale bits
    TMR1 = 0X0000;
    
    IFS0bits.T1IF = 0;
    IEC0bits.T1IE = 0;      //Timer1 ISR call, disabled to use ADC interrupt
    IPC0bits.T1IP = 4;
    
    IFS0bits.AD1IF = 0;
    IEC0bits.AD1IE = 1;     //Enable ADC1 Conversion complete interrupt (disable to use Timer interrupt)
    IPC3bits.AD1IP = 4;     // Set priority level to 4
    ResetControlDispatcher();
}

int main(void)
{
    InitClock();            // Initialize Device Oscillator (FRC w/ PLL and Aux)
    InitIOPorts();          // Initialize all I/O Ports
    InitUart();             // Setup UART

    // initialize PIL framework
    PIL_init();
    PIL_setLinkParams((unsigned char*)&PIL_D_Guid[0], (PIL_CommCallbackPtr_t)PollUart);
    PIL_setCtrlCallback((PIL_CtrlCallbackPtr_t)PilCallback);
    PilInitOverrideProbes();
    PilInitCalibrations();

    // initialize control task(s)
    InitControl();

    InitControlDispatcher();
    T1CONbits.TON = 1;      // Turn on timer 1
    AD1CON1bits.ADON = 1;   //Enable ADC module
    // get ready for PIL
    PIL_requestReadyMode();

    BackgroundLoopCtr = 0;
    while(1)
    {
       BackgroundLoopCtr++;
       PIL_backgroundCall();
    }
}




