/*
        Copyright (c) 2014 by Plexim GmbH
        All rights reserved.

        A free license is granted to anyone to use this software for any legal
        non safety-critical purpose, including commercial applications, provided
        that:
        1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
        2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

        THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
        OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
        FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
        AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
        LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
        OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
        SOFTWARE.
 */

//#include <p33Fxxxx.h>
#include <p33FJ128MC802.h>
#include "pil.h"
#include "control.h"


extern uint16_t BackgroundLoopCtr;
extern void ResetControlDispatcher();

void PilCallback(PIL_CtrlCallbackReq_t aCallbackReq)
{
    switch (aCallbackReq)
    {
        case PIL_CLBK_ENTER_NORMAL_OPERATION_REQ:
            // enabling the hardware actuation (if desired by user)
            PIL_inhibitPilSimulation();
            ResetControl();
            EnableActuation();
            return;

        case PIL_CLBK_LEAVE_NORMAL_OPERATION_REQ:
            // stopping the hardware actuation or invoking a transfer to a safe system state
            DisableActuation();
            PIL_allowPilSimulation();
            return;

        case PIL_CLBK_INITIALIZE_SIMULATION:
            ResetControlDispatcher();
            // resetting the controller variables
            ResetControl();
            BackgroundLoopCtr = 0;
            return;

        case PIL_CLBK_TERMINATE_SIMULATION:
            //Termination Request
            PilInitCalibrations();
            break;

        case PIL_CLBK_STOP_TIMERS:
            // stop relevant timers
            T1CONbits.TON = 0;
            P1TCONbits.PTEN = 0;   // Disabling the PWM timer
            return;

        case PIL_CLBK_START_TIMERS:
            // start relevant timers
            T1CONbits.TON = 1;
            P1TCONbits.PTEN = 1;   // Enabling the PWM timer
            return;
    }
}