/*
   Copyright (c) 2015 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
*/

#ifndef CONTROL_H_
#define CONTROL_H_

#include "pil.h"
#include "hall.h"

//global structure for control variables
struct CONTROL_VARS
{
   uint16_t Fs;
   uint16_t Fpwm;
   int16_t Vmax;
   bool_t ClosedFlag;

   //PIL Extension for probed variables
	 PIL_OVERRIDE_PROBE(int16_t,Iset,Q_IV,I_REF,"A");

   int16_t Ierr;
   PIL_READ_PROBE(int16_t,Vset,Q_IV, V_REF, "V");
   int16_t MPosition;
   int16_t MPos0Angle;
   int16_t MSpeed;
   int16_t MPos0;
   int16_t MPos0Last;
   int16_t MPosAccumulated;
   int16_t MPosAccuCtr;
   int16_t CmtnPointer;      // Input: Commutation (or switching) state pointer input (Q0) ;
   int16_t DutyFunc;   	    // Input: PWM period modulation input (Q15)
   uint16_t PosInc;
   uint32_t PosCtr;
   uint16_t Pos; 
};

extern struct CONTROL_VARS ControlVars;

//global structure for analog inputs
struct ANALOG_INPUTS
{
   int16_t Iu;
   int16_t Iv;
   int16_t Iw;

   //PIL Extension for probed variables
   PIL_OVERRIDE_PROBE(int16_t,Idc, Q_IV, I_REF, "A");

   int16_t Vu;
   int16_t Vv;
   int16_t Vw;
   int16_t Trim;

   uint32_t IuAccu;
   uint32_t IvAccu;
   uint32_t IwAccu;
   uint32_t IdcAccu;

   uint16_t IuOffset;
   uint16_t IvOffset;
   uint16_t IwOffset;
   uint16_t IdcOffset;

   uint16_t AccuCtr;
};

extern struct ANALOG_INPUTS AIn;

extern HALL3 Hall1;

extern void readInputs(void);
extern void initControl(void);
extern void stopControl(void);
extern void startControl(void);
extern void resetControl(void);
extern void controlStep(void);

#endif /*CONTROL_H_*/
