/*
   Copyright (c) 2015 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
*/

#include "main.h"
#include "gpio.h"
#include "hall.h"

/*
 * Initializes control task.
 */
void initHall3(HALL3 *aV)
{
   //Disable EALLOW
   determineHALL3State(aV);
   aV->HallGpioBuffer = aV->HallGpio;     //Init with current GPIO logic levels
   aV->HallGpioAccepted = aV->HallGpio;   //Init with current GPIO logic levels
}

/*
 * Determine HALL State
 */
void determineHALL3State(HALL3 *aV)
{
   uint16_t HallGpioBitA = GPIO_ReadInputDataBit(Hall_GPIO_PORT,HallA_PIN);
	 uint16_t HallGpioBitB = GPIO_ReadInputDataBit(Hall_GPIO_PORT,HallB_PIN);
	 uint16_t HallGpioBitC = GPIO_ReadInputDataBit(Hall_GPIO_PORT,HallC_PIN);
   //Shift for HallGpio calculation
   HallGpioBitA = HallGpioBitA;
   HallGpioBitB = HallGpioBitB << 1;
   HallGpioBitC = HallGpioBitC << 2;

   //***************************************************************************************************************
   //HallGPIO is a Probed Variable -> write access needs to be replaced by SET_OPROBE

   //Original Code:

   //v->HallGpio = HallGpioBitA + HallGpioBitB + HallGpioBitC;

   //Replacement:

   SET_OPROBE(aV->HallGpio, HallGpioBitA + HallGpioBitB + HallGpioBitC);

   //***************************************************************************************************************
}
