/*
   Copyright (c) 2015 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
*/

#include "main.h"

/*
 * Receive character 
 */
int16_t getSCIChar(void)
{
	uint8_t result;
	//Check buffer for received char
#ifdef USE_USART
	result = TM_USART_Getc(USART1);
#else
	TM_USB_VCP_Getc(&result);
#endif
	return (int16_t)result;
}

/*
 * Transmit character 
 */
void putSCIChar(int16_t aC)
{
#ifdef USE_USART
	 TM_USART_Putc(USART1,aC);
#else
	 TM_USB_VCP_Putc(aC);
#endif	
}

/*
 * Write string
 */
void writeSCIString(const char *aS)
{
#ifdef USE_USART
	 TM_USART_Puts(USART1,(char*)aS);
#else
	 //not implemented
#endif	
}

/*
 * Function to Poll the Communication Link -> used by PIL Framework as PilCommFnc
 */
void pollSCI(void)
{
		  int16_t ch;			
			//get incoming bytes
#ifdef USE_USART
		  while(!TM_USART_BufferEmpty(USART1))
			{
				//Forward Byte to PIL Framework
				PIL_RA_serialIn((int16_t)TM_USART_Getc(USART1));
			}	
#else
	 		uint8_t result;
			while(TM_USB_VCP_Getc(&result) == TM_USB_VCP_DATA_OK)
      {
         //Forward Byte to PIL Framework
         PIL_RA_serialIn((int16_t)result);
      }
#endif
			//send one byte -> called multiple times from framework      
      if(PIL_RA_serialOut(&ch))
      {
        putSCIChar(ch);
      } 
}

/*
 * Function initialize the Communication Link
 */
void initSCI(uint32_t aBaudRate)
{
#ifdef USE_USART
	//Init NVIC Priority Group to 1
	NVIC_PriorityGroupConfig(NVIC_PriorityGroup_1);
	/* Initialize USART1 at 115200 baud, TX: PB6, RX: PB7*/
	//make sure that USART1_IRQHandler has higher priority than TIM1_IRQHandler
	TM_USART_Init(USART1, TM_USART_PinsPack_2, aBaudRate);
#else	
	/* Initialize USB VCP */
  //make sure that OTG_FS_IRQHandler has higher priority than TIM3_IRQHandler
	//-> needed for communication in the loop during PIL Simulation
  TM_USB_VCP_Init();
#endif
}

