/*
   Copyright (c) 2014 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

#ifndef F2806x_BLDC_PWM
#define F2806x_BLDC_PWM

/*
* Initialization constant for the F280X Time-Base Control Registers for PWM Generation.
* Sets up the timer to run free upon emulation suspend, count up mode
* prescaler 1.
*/
#define BLDCPWM_INIT_STATE ( FREE_RUN_FLAG +         \
                            PRDLD_IMMEDIATE  +       \
                            TIMER_CNT_UP +         \
                            HSPCLKDIV_PRESCALE_X_1 + \
                            CLKDIV_PRESCALE_X_1  +   \
                            PHSDIR_CNT_UP    +       \
                            CNTLD_DISABLE )


//Initialization constant for the F280X Compare Control Register.
#define BLDCPWM_CMPCTL_INIT_STATE ( LOADAMODE_ZRO + \
                                   LOADBMODE_ZRO + \
                                   SHDWAMODE_SHADOW + \
                                   SHDWBMODE_SHADOW )


//Initialization constant for the F280X Action Qualifier Output A Register.
#define  BLDCPWM_AQCTLA_INIT_STATE  CAU_SET


//Initialization constant for the F280X Dead-Band Control Generator register.
#define  BLDCPWM_DBCTL_INIT_STATE  BP_DISABLE


//Initialization constant for the F280X PWM Chopper Control register for PWM Generation.
#define  BLDCPWM_PCCTL_INIT_STATE  CHPEN_DISABLE

//Initialization constant for the F280X Trip Zone Select Register
#define  BLDCPWM_TZSEL_INIT_STATE  DISABLE_TZSEL


//Define the structure of the PWM Driver Object
typedef struct
{
   Uint16 CmtnPointer;     // Input: Commutation (or switching) state pointer input (Q0)
   int16 MfuncPeriod;      // Input: Duty ratio of the PWM outputs (Q15)
   Uint16 PeriodMax;    	// Parameter: Maximum period (Q0)
   int16 DutyFunc;   	   // Input: PWM period modulation input (Q15)
   Uint16 PwmActive;       // Parameter: 0 = PWM active low, 1 = PWM active high (0 or 1)
} PWMGEN;

/*
* The "PwmActive" setting depends on Power devices.
* when PwmActive = 1 (active high) implies the power device turns ON with a HIGH gate signal.
* PwmActive = 0 (active low) implies the power device turns ON with a LOW gate signal.
*/

//Define a structure for PWM_module Configuration mirroring
typedef struct
{
   PIL_READ_PROBE(int16,PWM1CMPA, 0, 1, "");// Compare A value
   PIL_READ_PROBE(int16,PWM1CMPB, 0, 1, "");// Compare B value
   PIL_READ_PROBE(int16,PWM1AQCSFRC, 0, 1, "");// Action Qualifier Continuous Software Force Register
   PIL_READ_PROBE(int16,PWM2CMPA, 0, 1, "");// Compare A value
   PIL_READ_PROBE(int16,PWM2AQCSFRC, 0, 1, "");// Action Qualifier Continuous Software Force Register
   PIL_READ_PROBE(int16,PWM3CMPA, 0, 1, "");// Compare A value
   PIL_READ_PROBE(int16,PWM3AQCSFRC, 0, 1, "");// Action Qualifier Continuous Software Force Register
} PWMCONF;

//Define a PWMGEN_handle
typedef PWMGEN *PWMGEN_handle;

//Define TBPRD
#define PWMPRD 0x1F40

//Default Initializers for the F281X PWMGEN Object
#define F2806X_BLDC_PWM_GEN   {0x0000, \
                                0x7FFF, \
                                PWMPRD, \
                                0x0000, \
                                0x0001, \
                             }
#define PWMGEN_DEFAULTS 	F2806X_BLDC_PWM_GEN

extern void initPWM(PWMGEN *aV);
extern void updatePWM(PWMGEN *aV);
#endif
