/*
   Copyright (c) 2014 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

//Project Include
#include "includes.h"

//Project Variables and function prototypes
Uint16 LEDTimer = 0;
extern Uint16 RamfuncsLoadStart, RamfuncsLoadEnd, RamfuncsRunStart;
void DeviceInit(void);
void MemCopy(Uint16 *SourceAddr, Uint16 *SourceEndAddr, Uint16 *DestAddr);
void InitFlash();

/**
 * Main interrupt routine
 */
interrupt void myTickFxn()
{
   PIL_beginInterruptCall();

   if (readInputs())
   {
      // read start/stop button
      if (START_PRESSED && !STOP_PRESSED)
      {
         // Request Normal Operation
         PIL_requestNormalMode();
      }
      if (STOP_PRESSED && !START_PRESSED)
      {
         //Request a safe state for a PIL simulation
         PIL_requestReadyMode();
      }
      controlStep();
   }

   //Acknowledge Int
   EPwm1Regs.ETCLR.bit.INT = 1;  // Clear INT flag for this timer
   PieCtrlRegs.PIEACK.all = PIEACK_GROUP3; // Acknowledge interrupt to PIE
   IER |= M_INT3;
   EINT;
   //Inc Led Timer
   LEDTimer++;
}

/**
 * Initialize the pwm interrupt
 */
void InitControlDispatcher()
{
	EPwm1Regs.ETSEL.bit.INTSEL = ET_CTR_PRD; // Select INT on period event
	EPwm1Regs.ETSEL.bit.INTEN = 1;           // Enable INT
	EPwm1Regs.ETPS.bit.INTPRD = ET_1ST; 	 // Generate interrupt on 1st event

	EALLOW;
	PieVectTable.EPWM1_INT = &myTickFxn;
	EDIS;
	PieCtrlRegs.PIEIER3.bit.INTx1 = 1;
	IER |= M_INT3;
}

/**
 * Blink the LED every second
 */
void BlinkLed(void)
{
	if(LEDTimer > 10000)
	{
		GpioDataRegs.GPBTOGGLE.bit.GPIO34 = 1;
		LEDTimer = 0;
	}
}

/**
 * Application entry point
 */
void main()
{
	 //Init Device with standard settings
	 DeviceInit();

     MemCopy(&RamfuncsLoadStart, &RamfuncsLoadEnd, &RamfuncsRunStart);

     InitFlash();

     //Reconfigure GPIO
     initGPIO();

     DINT;
	    IER = 0x0000;
		IFR = 0x0000;
	 EALLOW;
		SysCtrlRegs.PCLKCR0.bit.TBCLKSYNC = 0;      // Stop all the TB clocks
     EDIS;

     //InitControlDispatcher
     InitControlDispatcher();

     //Initialize Communication Interface
     SCIInit(ONE_STOPBIT + NO_PARITY + EIGHT_BITS, BAUD_RATE, LSPCLK_HZ);

     //Configure PIL Framework
     PIL_init();
     PIL_setLinkParams(PIL_D_Guid, (PIL_CommCallbackPtr_t)SCIPoll);
     PIL_setCtrlCallback(PilCallback);

     //Initialize Override Probes and Calibrations
     PilInitOverrideProbes();
     PilInitCalibrations();

     //Initialize control system
     initControl();

     // Enable global Interrupts and higher priority real-time debug events:
     EINT;   // Enable Global interrupt INTM
     ERTM;   // Enable Global realtime interrupt DBGM

     EALLOW;
		SysCtrlRegs.PCLKCR0.bit.TBCLKSYNC = 1;         // Start all the timers synced
     EDIS;

     //Request PIL Ready Mode
     PIL_requestReadyMode();

     // main-loop
     for(;;)
	   {
		   BlinkLed();
		   PIL_backgroundCall();
	   }
}
