/*
   Copyright (c) 2014 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

#ifndef _CALIB_H_
#define _CALIB_H_

#include "pil.h"
#include "pu.h"

struct CALIBRATIONS {
		PIL_CALIBRATION(int16_t, dcVoltageGain, Q_IV, VDC_REF, "V", 0, VDC_REF,
				(1000.0 / (double)(1 << (12-Q_IV))));
		PIL_CALIBRATION(int16_t, acVoltageGain, Q_IV, VP_REF, "V", 0, VDC_REF,
				(1000.0 / (double)(1 << (11-Q_IV))));
		PIL_CALIBRATION(int16_t, currentGain, Q_IV, I_REF, "A", 0, I_REF,
				(375.0  / (double)(1 << (11-Q_IV))));

		PIL_CALIBRATION(int16_t, VdcOff, Q_IV, VDC_REF, "V", 0, VDC_REF,
				0.5 * (double)VDC_REF);
		PIL_CALIBRATION(int16_t, VdcOn, Q_IV, VDC_REF, "V", 0, VDC_REF,
				0.6 * (double)VDC_REF);
		PIL_CALIBRATION(int16_t, VGridMin, Q_IV, VP_REF, "V", 0, VP_REF,
				100.0 * 1.41);

		PIL_CALIBRATION(int16_t, KpD, PLX_PIDQ_Q_KP, R_REF, "Ohm", 0, R_REF,
				0.86);
		PIL_CALIBRATION(int16_t, KiD, PLX_PIDQ_Q_KI, R_REF, "Ohm", 0, R_REF,
				0.0038);
		PIL_CALIBRATION(int16_t, KpQ, PLX_PIDQ_Q_KP, R_REF, "Ohm", 0, R_REF,
				0.86);
		PIL_CALIBRATION(int16_t, KiQ, PLX_PIDQ_Q_KI, R_REF, "Ohm", 0, R_REF,
				0.0038);

		PIL_CALIBRATION(int16_t, KpMid, 0, INV_VDC_REF, "1/V", 0, INV_VDC_REF*10000.0,
				0.1);
		PIL_CALIBRATION(int16_t, MidErrSat, Q_IV, VDC_REF, "V", 0, VDC_REF,
				(0.5 / 0.1));

		PIL_CALIBRATION(int16_t, KpPll, PLX_PI_Q_KP, F_REF, "Hz", 0, F_REF*10,
				150.0);
		PIL_CALIBRATION(int16_t, KiPll, PLX_PI_Q_KI, F_REF, "Hz", 0, F_REF,
				1.5);
		PIL_CALIBRATION(int16_t, omegaMaxPll, Q_WF, F_REF, "Hz", 0, F_REF*10,
				100.0);
		PIL_CALIBRATION(int16_t, omega0Pll, Q_WF, F_REF, "Hz", 0, F_REF,
				60.0);
		PIL_CALIBRATION(uint16_t, lockAnglePll, 16, 1, "rev", 0, 1.0,
				0.02);
		PIL_CALIBRATION(uint16_t, lockTicksPll, 0, 1, "ticks", 0, 65535,
				100);
		PIL_CALIBRATION(uint16_t, unlockAnglePll, 16, 1, "rev", 0, 1.0,
				0.03);
		PIL_CALIBRATION(uint16_t, unlockTicksPll, 0, 1, "ticks", 0, 65535,
				10);

		PIL_CALIBRATION(int16_t, KpSms,  Q_WF, INV_F_REF, "s", -INV_F_REF*10, INV_F_REF*10,
				(-0.1 / (2.0 * 3.14)));
		PIL_CALIBRATION(int16_t, SmsErrSat, Q_WF, F_REF, "Hz", 0, F_REF,
				(0.5 / (0.1 / (2.0 * 3.14))));
};

extern struct CALIBRATIONS Calib;

#endif
