/*
   Copyright (c) 2014 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

#include "includes.h"

struct ANALOG_INPUTS AIn;
struct ADC_OPROBES AdcOvrProbes;

void InitADC()
{
	EALLOW;

	CpuSysRegs.PCLKCR13.bit.ADC_A = 1;

	//write configurations
	AdcaRegs.ADCCTL2.bit.PRESCALE = 6; //set ADCCLK divider to /4
    AdcSetMode(ADC_ADCA, ADC_RESOLUTION_12BIT, ADC_SIGNALMODE_SINGLE);

	//Set pulse positions to late
	AdcaRegs.ADCCTL1.bit.INTPULSEPOS = 1;

	//power up the ADC
	AdcaRegs.ADCCTL1.bit.ADCPWDNZ = 1;

	//delay for 1ms to allow ADC time to power up
	PLX_DELAY_US(1000);

	// Configure (three dummy) channels
	EALLOW;
	AdcaRegs.ADCSOCPRICTL.bit.SOCPRIORITY = 0; // round-robin - now high priority channels

	AdcaRegs.ADCSOC0CTL.bit.CHSEL = 1;
	AdcaRegs.ADCSOC0CTL.bit.TRIGSEL = 5; // trigger on EPWM1A, SOCA
	AdcaRegs.ADCSOC0CTL.bit.ACQPS = 6; // Set SOC0 S/H Window to 7 ADC Clock Cycles, (6 ACQPS plus 1)

	AdcaRegs.ADCSOC1CTL.bit.CHSEL = 9;
	AdcaRegs.ADCSOC1CTL.bit.TRIGSEL = 5;
	AdcaRegs.ADCSOC1CTL.bit.ACQPS = 6;

	AdcaRegs.ADCSOC2CTL.bit.CHSEL = 10;
	AdcaRegs.ADCSOC2CTL.bit.TRIGSEL = 5;
	AdcaRegs.ADCSOC2CTL.bit.ACQPS = 6;
	EDIS;

	// default offset calibration
    AIn.IuOffset = 0x800;
    AIn.IvOffset = 0x800;
    AIn.IuOffset = 0x800;
    AIn.VguvOffset = 0x800;
    AIn.VgvwOffset = 0x800;
}

void InitPWM(uint16_t aPeriod){
	EALLOW;
	CpuSysRegs.PCLKCR2.bit.EPWM1 = 1; // ePWM1
	CpuSysRegs.PCLKCR2.bit.EPWM2 = 1; // ePWM2
	CpuSysRegs.PCLKCR2.bit.EPWM3 = 1; // ePWM3
	CpuSysRegs.PCLKCR2.bit.EPWM4 = 1; // ePWM4
	CpuSysRegs.PCLKCR2.bit.EPWM5 = 1; // ePWM5
	CpuSysRegs.PCLKCR2.bit.EPWM6 = 1; // ePWM6
	CpuSysRegs.PCLKCR2.bit.EPWM7 = 1; // ePWM7
	CpuSysRegs.PCLKCR2.bit.EPWM8 = 1; // ePWM8
	ClkCfgRegs.PERCLKDIVSEL.bit.EPWMCLKDIV = 1;
	EDIS;

	// EPWM Module 1 config
	EPwm1Regs.TBPRD = aPeriod;
	EPwm1Regs.TBPHS.bit.TBPHS = 0; // Set Phase register to zero
	EPwm1Regs.TBCTL.bit.CTRMODE = TB_COUNT_UPDOWN; // Symmetrical mode
	EPwm1Regs.TBCTL.bit.PHSEN = TB_DISABLE; // Master module
	EPwm1Regs.TBCTL.bit.PRDLD = TB_SHADOW;
	EPwm1Regs.TBCTL.bit.SYNCOSEL = TB_CTR_ZERO; // Sync down-stream module
	EPwm1Regs.CMPCTL.bit.SHDWAMODE = CC_SHADOW;
	EPwm1Regs.CMPCTL.bit.SHDWBMODE = CC_SHADOW;
	EPwm1Regs.CMPCTL.bit.LOADAMODE = CC_CTR_ZERO; // load on CTR=Zero
	EPwm1Regs.CMPCTL.bit.LOADBMODE = CC_CTR_ZERO; // load on CTR=Zero
	EPwm1Regs.AQCTLA.bit.CAU = AQ_SET; // set actions for EPWM1A
	EPwm1Regs.AQCTLA.bit.CAD = AQ_CLEAR;
	EPwm1Regs.DBCTL.bit.OUT_MODE = DB_FULL_ENABLE; // enable Dead-band module
	EPwm1Regs.DBCTL.bit.POLSEL = DB_ACTV_HIC; // Active Hi complementary
	EPwm1Regs.DBFED = 50; // FED = 50 TBCLKs
	EPwm1Regs.DBRED = 50; // RED = 50 TBCLKs

	// EPWM Module 2 config
	EPwm2Regs.TBPRD = aPeriod;
	EPwm2Regs.TBPHS.bit.TBPHS = 0; // Set Phase register to zero
	EPwm2Regs.TBCTL.bit.CTRMODE = TB_COUNT_UPDOWN; // Symmetrical mode
	EPwm2Regs.TBCTL.bit.PHSEN = TB_ENABLE; // Slave module
	EPwm2Regs.TBCTL.bit.PRDLD = TB_SHADOW;
	EPwm2Regs.TBCTL.bit.SYNCOSEL = TB_SYNC_IN; // sync flow-through
	EPwm2Regs.CMPCTL.bit.SHDWAMODE = CC_SHADOW;
	EPwm2Regs.CMPCTL.bit.SHDWBMODE = CC_SHADOW;
	EPwm2Regs.CMPCTL.bit.LOADAMODE = CC_CTR_ZERO; // load on CTR=Zero
	EPwm2Regs.CMPCTL.bit.LOADBMODE = CC_CTR_ZERO; // load on CTR=Zero
	EPwm2Regs.AQCTLA.bit.CAU = AQ_SET; // set actions for EPWM2A
	EPwm2Regs.AQCTLA.bit.CAD = AQ_CLEAR;
	EPwm2Regs.DBCTL.bit.OUT_MODE = DB_FULL_ENABLE; // enable Dead-band module
	EPwm2Regs.DBCTL.bit.POLSEL = DB_ACTV_HIC; // Active Hi complementary
	EPwm2Regs.DBFED = 50; // FED = 50 TBCLKs
	EPwm2Regs.DBRED = 50; // RED = 50 TBCLKs

	// EPWM Module 3 config
	EPwm3Regs.TBPRD = aPeriod;
	EPwm3Regs.TBPHS.bit.TBPHS = 0; // Set Phase register to zero
	EPwm3Regs.TBCTL.bit.CTRMODE = TB_COUNT_UPDOWN; // Symmetrical mode
	EPwm3Regs.TBCTL.bit.PHSEN = TB_ENABLE; // Slave module
	EPwm3Regs.TBCTL.bit.PRDLD = TB_SHADOW;
	EPwm3Regs.TBCTL.bit.SYNCOSEL = TB_SYNC_IN; // sync flow-through
	EPwm3Regs.CMPCTL.bit.SHDWAMODE = CC_SHADOW;
	EPwm3Regs.CMPCTL.bit.SHDWBMODE = CC_SHADOW;
	EPwm3Regs.CMPCTL.bit.LOADAMODE = CC_CTR_ZERO; // load on CTR=Zero
	EPwm3Regs.CMPCTL.bit.LOADBMODE = CC_CTR_ZERO; // load on CTR=Zero
	EPwm3Regs.AQCTLA.bit.CAU = AQ_SET; // set actions for EPWM3A
	EPwm3Regs.AQCTLA.bit.CAD = AQ_CLEAR;
	EPwm3Regs.DBCTL.bit.OUT_MODE = DB_FULL_ENABLE; // enable Dead-band module
	EPwm3Regs.DBCTL.bit.POLSEL = DB_ACTV_HIC; // Active Hi complementary
	EPwm3Regs.DBFED = 50; // FED = 50 TBCLKs
	EPwm3Regs.DBRED = 50;
}


